diff src/share/vm/runtime/thread.hpp @ 16006:66a9286203a2

decoupled Graal runtime initialization and Graal compilation queue initialization
author Doug Simon <doug.simon@oracle.com>
date Tue, 03 Jun 2014 11:51:27 +0200
parents a20be10ad437
children 774349ad0b03
line wrap: on
line diff
--- a/src/share/vm/runtime/thread.hpp	Tue Jun 03 11:01:58 2014 +0200
+++ b/src/share/vm/runtime/thread.hpp	Tue Jun 03 11:51:27 2014 +0200
@@ -922,8 +922,8 @@
 
 #ifdef GRAAL
   address   _graal_alternate_call_target;
-  address   _graal_implicit_exception_pc;  // pc at which the most recent implicit exception occurred
-  bool      _graal_compiling;
+  address   _graal_implicit_exception_pc;    // pc at which the most recent implicit exception occurred
+  bool      _graal_can_schedule_compilation; // see NoGraalCompilationScheduling
 
   jlong*    _graal_counters;
 
@@ -1310,8 +1310,8 @@
 #ifdef GRAAL
   void set_graal_alternate_call_target(address a) { _graal_alternate_call_target = a; }
   void set_graal_implicit_exception_pc(address a) { _graal_implicit_exception_pc = a; }
-  bool is_graal_compiling()                       { return _graal_compiling;          }
-  void set_is_graal_compiling(bool b)             { _graal_compiling = b;             }
+  bool can_schedule_graal_compilation()           { return _graal_can_schedule_compilation; }
+  void set_can_schedule_graal_compilation(bool b) { _graal_can_schedule_compilation = b;    }
 #endif
 
   // Exception handling for compiled methods